# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`jmxtrans`](#jmxtrans): This is the main class for using jmxtrans. It should be included before using anything else from the module.
* [`jmxtrans::config`](#jmxtransconfig): This class is used to configure the jmxtrans config files
* [`jmxtrans::install`](#jmxtransinstall): This class is used to install the jmxtrans package. If `$::jmxtrans::package_name` is undef, then this class will do nothing. If `$::jmxtrans
* [`jmxtrans::service`](#jmxtransservice): This class manages the jmxtrans service. If `$::jmxtrans::service_name` is undef, this class does nothing.

### Defined types

* [`jmxtrans::query`](#jmxtransquery): This defined type is used to add a JSON configuration for jmxtrans to pull metrics for a given JVM process and write them out. It can automat

### Functions

* [`jmxtrans::merge_notundef`](#jmxtransmerge_notundef): This function will merge a list of hashes, ignoring key => value pairs in the the latter which have a value of `undef`
* [`jmxtrans::to_json`](#jmxtransto_json): Stringify data into the JSON format

## Classes

### <a name="jmxtrans"></a>`jmxtrans`

This is the main class for using jmxtrans. It should be included before using
anything else from the module.

#### Examples

##### jmxtrans is installed via some other method

```puppet
include jmxtrans
```

##### jmxtrans is available in a repository via the package `jmxtrans`

```puppet
class { 'jmxtrans':
  package_name => 'jmxtrans',
  service_name => 'jmxtrans',
}
```

##### jmxtrans should be installed via rpm installing a remote package

```puppet
class { 'jmxtrans':
  package_name  => 'jmxtrans',
  service_name  => 'jmxtrans',
  package_source => 'http://central.maven.org/maven2/org/jmxtrans/jmxtrans/254/jmxtrans-254.rpm',
}
```

##### jmxtrans runs under a different user with a different config path

```puppet
class { 'jmxtrans':
  config_directory => '/etc/jmxtrans/config/',
  user             => 'java',
}
```

#### Parameters

The following parameters are available in the `jmxtrans` class:

* [`package_name`](#package_name)
* [`service_name`](#service_name)
* [`package_source`](#package_source)
* [`package_provider`](#package_provider)
* [`working_directory`](#working_directory)
* [`systemd_environment_file`](#systemd_environment_file)
* [`manage_service_file`](#manage_service_file)
* [`package_version`](#package_version)
* [`systemd_template`](#systemd_template)
* [`binary_path`](#binary_path)
* [`config_directory`](#config_directory)
* [`user`](#user)

##### <a name="package_name"></a>`package_name`

Data type: `Optional[String[1]]`

The package to install. Skips managing the package if undef.

Default value: ``undef``

##### <a name="service_name"></a>`service_name`

Data type: `Optional[String[1]]`

The service to manage. Skips managing the service if undef.

Default value: ``undef``

##### <a name="package_source"></a>`package_source`

Data type: `Optional[String[1]]`

A URL or local path to get a package from.

Default value: ``undef``

##### <a name="package_provider"></a>`package_provider`

Data type: `Optional[String[1]]`

Used to explicitly set the provider to use to install the package.

Default value: ``undef``

##### <a name="working_directory"></a>`working_directory`

Data type: `Optional[String[1]]`

Sets the working directory for the jmxtrans processes.

Default value: ``undef``

##### <a name="systemd_environment_file"></a>`systemd_environment_file`

Data type: `Optional[String[1]]`

Path to the file where the environment variables needed by
the jmxtrans service should be defined (e.g. '/etc/default/jmxtrans' or '/etc/sysconfig/jmxtrans').

Default value: ``undef``

##### <a name="manage_service_file"></a>`manage_service_file`

Data type: `Boolean`

Manage the service definition file (systemd/init) for the JMXtrans-Service

Default value: ``false``

##### <a name="package_version"></a>`package_version`

Data type: `String[1]`

The version of the package to be installed. Defaults to 'present'.

Default value: `present`

##### <a name="systemd_template"></a>`systemd_template`

Data type: `String[1]`

Template to be be used to generate the systemd unit. Defaults to 'jmxtrans/jmxtrans.service.pp'

Default value: `'jmxtrans/jmxtrans.service.epp'`

##### <a name="binary_path"></a>`binary_path`

Data type: `String[1]`

Path to the jmxtrans executable. Defaults to '/usr/share/jmxtrans/bin/jmxtrans'.

Default value: `'/usr/share/jmxtrans/bin/jmxtrans'`

##### <a name="config_directory"></a>`config_directory`

Data type: `String[1]`

Where to place JSON configurations. Defaults to '/var/lib/jmxtrans'.

Default value: `'/var/lib/jmxtrans'`

##### <a name="user"></a>`user`

Data type: `String[1]`

The user who will own the JSON configurations. Defaults to 'jmxtrans'.

Default value: `'jmxtrans'`

### <a name="jmxtransconfig"></a>`jmxtrans::config`

This class is used to configure the jmxtrans config files

### <a name="jmxtransinstall"></a>`jmxtrans::install`

This class is used to install the jmxtrans package. If
`$::jmxtrans::package_name` is undef, then this class will do nothing. If
`$::jmxtrans::package_source` is set, the package will be installed from the
location specified.

This class will use the default provider for a platform if an explicit
value is not set for `$::jmxtrans::package_source`. If a value is set for
that parameter, this class will use the `rpm` provider on RedHat systems and
the `dpkg` provider on Debian systems. This can be overridden by specifying a
value for the `$::jmxtrans::package_provider` parameter.

### <a name="jmxtransservice"></a>`jmxtrans::service`

This class manages the jmxtrans service. If `$::jmxtrans::service_name` is
undef, this class does nothing.

## Defined types

### <a name="jmxtransquery"></a>`jmxtrans::query`

This defined type is used to add a JSON configuration for jmxtrans to pull
metrics for a given JVM process and write them out. It can automatically
configure the GraphiteWriter, or you can pass explicit configuration for any
other jmxtrans-supported writer.

#### Parameters

The following parameters are available in the `jmxtrans::query` defined type:

* [`title`](#title)
* [`ensure`](#ensure)
* [`host`](#host)
* [`port`](#port)
* [`username`](#username)
* [`password`](#password)
* [`num_threads`](#num_threads)
* [`stdout`](#stdout)
* [`graphite`](#graphite)
* [`gelf`](#gelf)
* [`queries`](#queries)

##### <a name="title"></a>`title`

The resource title is used for the server `alias`.

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Whether the configuration should exist or not.

Default value: `'present'`

##### <a name="host"></a>`host`

Data type: `String[1]`

The host to connect to JMX on. Defaults to `$title`.

Default value: `$title`

##### <a name="port"></a>`port`

Data type: `Optional[Integer[1]]`

The port to connect to JMX on.

Default value: ``undef``

##### <a name="username"></a>`username`

Data type: `Optional[String[1]]`

The username to use to connect to JMX.

Default value: ``undef``

##### <a name="password"></a>`password`

Data type: `Optional[String[1]]`

The password to use to connect to JMX.

Default value: ``undef``

##### <a name="num_threads"></a>`num_threads`

Data type: `Optional[Integer[1]]`

How many queries to execute
concurrently. Defaults to `undef`, which will execute the queries serially.

Default value: ``undef``

##### <a name="stdout"></a>`stdout`

Data type: `Boolean`

Set to `true` to enable the StdoutWriter for each
query on this object, so you don't have to do it manually.

Default value: ``false``

##### <a name="graphite"></a>`graphite`

Data type: `Optional[Struct[{
    host => String[1],
    port => Integer[1],
    Optional[root] => String[1],
    Optional[boolean_as_number] => Boolean,
  }]]`

The Graphite configuration.  Passing a hash
with `host` and `port` will configure the GraphiteWriter for each query on
this object, so you don't have to do it manually. You may also set:

- `root` [String] to configure the `rootPrefix`
- `boolean_as_number` [String] to configure the `booleanAsNumber`

Default value: ``undef``

##### <a name="gelf"></a>`gelf`

Data type: `Optional[Struct[{
    host => String[1],
    port => Integer[1],
    Optional[additionalFields] => Hash,
    Optional[transport] => String,
    Optional[queueSize] => Integer,
    Optional[connectTimeout] => Integer,
    Optional[reconnectDelay] => Integer,
    Optional[tcpNoDelay] => Boolean,
    Optional[sendBufferSize] => Integer,
    Optional[tlsEnabled] => Boolean,
    Optional[tlsTrustCertChainFile] => String,
    Optional[tlsCertVerificationEnabled] => Boolean,
    Optional[tcpKeepAlive] => Boolean,
    Optional[maxInflightSends] => Integer,
  }]]`

The GelfWriter configuration. Passing a hash with
`host`and `port` will configure the GelfWriter for each query on this object, so
you don't have to do it manually. You may also set additional parameters as documented
in the [JMXTrans Wiki](https://github.com/jmxtrans/jmxtrans/wiki/GELFWriter)

Default value: ``undef``

##### <a name="queries"></a>`queries`

Data type: `Optional[Array[Struct[{
    object => String[1],
    attributes => Array[String[1]],
    Optional[type_names] => Array[String[1]],
    Optional[result_alias] => String[1],
    Optional[writers] => Array[Hash],
  }]]]`

An array of queries to configure on the object. These
consist of hashes of the form:

~~~
{
  'object'       => 'net.sf.ehcache:typeCacheStatistics,*',
  'attributes'   => [ 'CacheHits', 'CacheMisses', 'ObjectCount' ],
  'type_names'   => ['name'],
  'result_alias' => 'ehcache',
  'writers'      => [
    {
      '@class'            => 'com.googlecode.jmxtrans.model.output.KeyOutWriter',
      'outputFile'        => '/tmp/keyout2.txt',
      'maxLogFileSize'    => '10MB',
      'maxLogBackupFiles' => '200',
      'debug'             => true,
    },
  ],
}
~~~

Default value: ``undef``

## Functions

### <a name="jmxtransmerge_notundef"></a>`jmxtrans::merge_notundef`

Type: Puppet Language

This function will merge a list of hashes, ignoring key => value pairs in the
the latter which have a value of `undef`

#### `jmxtrans::merge_notundef(Hash $original, Hash $to_merge)`

This function will merge a list of hashes, ignoring key => value pairs in the
the latter which have a value of `undef`

Returns: `Any` Merged list

##### `original`

Data type: `Hash`

The base hash. All key values from this will be included.

##### `to_merge`

Data type: `Hash`

A variable number of hashes to merge in. Each of these
will have its key => value pairs added to the original hash, except where
the value is `undef`. Later values will override earlier values.

### <a name="jmxtransto_json"></a>`jmxtrans::to_json`

Type: Ruby 4.x API

Stringify data into the JSON format

#### `jmxtrans::to_json(Data $data)`

Stringify data into the JSON format

Returns: `Any` Generated JSON string

##### `data`

Data type: `Data`

Data to stringify

